function [ float_metadata ] = float_metadata( p_filename )
%FLOAT_METADATA Loads the given metadata file.
%   If p_filename is a directory, all files with the .xml extension are
%   being selected and loaded.
%
%   Parameters:
%   p_filename:             The file or folder to be loaded.
%
%   Returns:
%   float_metadata:         The loaded metadata files in a cell.

%% Initialize return value
float_metadata = false;

%% Parameter is already being checked in nemo.load.xml_file
float_metadata = nemo.load.xml_file(p_filename);

switch (class(float_metadata))
    case 'struct'
        float_metadata.MISSION_PARAMETERS = ...
            nemo.float.process_mission_parameter(float_metadata.MISSION_PARAMETER_STRING);
    case 'cell'
        for i = 1:length(float_metadata)
            float_metadata{i}.MISSION_PARAMETERS = ...
                nemo.float.process_mission_parameter(float_metadata{i}.MISSION_PARAMETER_STRING);
        end
    otherwise
        warning([mfilename ': Something went wrong while loading the xml file(s)!']);
        return;
end


end

